==> newsx_0.11.orig.tar.gz: newsx-0.11/src/proto.h <==
/*  VER 095  TAB P   $Id: proto.h,v 1.2 1997/08/14 13:39:44 src Exp $
 *
 *  function prototypes
 *
 *  copyright 1996, 1997 Egil Kvaleberg, egil@kvaleberg.no
 *  the GNU General Public License applies
 */

/* doit.c */
int 
doit(void);

/* statistics.c */
void	    
statistics(time_t starttime,time_t endtime);

/* despool.c */
void 
despool(char *article_name);
char *
despool_line(void);

/* putarticle.c */
char *
submit_article(char *articlename);

/* lock.c */
void 
lock(char *dir_name,char *lock_name);
void 
unlock(void);
void 
unlock_exit(int n);

/* util.c */
char *
news_home(void);
int 
append_file(FILE *f,char *name,FILE *af);
int 
rename_file(char *from,char *to);
time_t
what_date(FILE *f,char *name);
time_t
how_old(FILE *f, char *name);
int 
is_regular(FILE *f, char *name);
void 
build_alt_filename(char *where,char *home,char *fixed,char *alt);
void 
build_filename(char *where,char *arg1,char *arg2,char *arg3,char *arg4);
char *
text_time(time_t t);

/* logmsg.c */
void 
log_open(void);
void 
log_msg(int type, char *fmt, ...);

/* server.c */
int 
open_server(char *host,char *port);
void 
close_server(void);
int 
get_server_nntp(char *line, int size);
int 
get_server_msg(char *line, int size);
void 
put_server(char *line);
int 
put_server_msg(char *line);

/* socket.c */
int 
socket_open(char *hostname, char *service, SOCKET_D *sock);
void 
socket_close(SOCKET_D *sock);
int 
get_socket(char *line, int size, SOCKET_D *sock);
int 
put_socket(char *line, SOCKET_D *sock);

/* getarticle.c */
int 
select_group(char *group,long *firstp,long *lastp);
int 
fetch_article(long where);

/* request.c */
int 
put_request(char *request, int (*fn)(), long where);
int 
flush_request(void);

/* pull.c */
void 
pull(char *hostname);
void 
pull_cleanup(void);

/* incoming.c */
int 
write_in_coming(char *buffer,long bytecount);
int 
flush_spool(void);

/* active.c */
int 
is_active(char *group);
int 
is_in_active(char *group);
int 
unseen_active(char *group);
void 
load_active(void);
void
clear_active(void);

/* sys.c */
void 
load_sys(void);
int 
sys_allow(char *group);

/* auth.c */
void 
get_authinfo(char *file);
void 
do_authinfo(char *username,char *password);
void 
do_mode_reader(void);

/* history.c */
void 
history_done(void);
int 
history_lookup(char *msgid);

/* msgid.c */
int 
new_msgid(char *msgid);

/* hash.c */
int 
hashindex(char *key,int hashlen);

/* exec.c */
int 
ctlinnd(char *arg1, char *arg2);
int 
script(char *program, int in, int out);
int	   
wait_pid(int pid);
void 
program_open(char *program, SOCKET_D *sock);
FILE *
fork_write(char *path, int *pidp, char *arg1, char *arg2);
FILE *
open_any(char *any,int *pidp);
int	
close_any(FILE *f,int pid);

/* telnet.c */
int 
read_telnet(char *line, int size, SOCKET_D *sock);
int 
write_telnet(char *line, SOCKET_D *sock);

/* script.c */
void 
chat_update(char *line,SOCKET_D *sock);

/* title.c */
void 
begintitle(int argc, char **argv, char **envp);
void 
settitle(char *name);
void 
progtitle(char *what);
void 
progtitle2(char *what,char *more);

/* wildmat.c */
int 
wildmat(char *text, char *p);

/* bounce.c */
int  
bounce_msg(char *to, FILE *art,char *filename, char *msgid, char *reason);

/* rnews.c */
FILE *
open_rnews(int *pid);
int 
close_rnews(FILE *f, int pid);

/* mfilter.c */
int  
do_mfilter(char *msgid);

/* list.c */
int  
get_list(void);
int  
get_desc(void);

==> newsx_1.2.orig.tar.gz: newsx-1.2/src/proto.h <==
/*  VER 136  TAB P   $Id: proto.h,v 1.17 1998/09/21 10:04:29 src Exp $
 *
 *  function prototypes
 *
 *  copyright 1996, 1997 Egil Kvaleberg, egil@kvaleberg.no
 *  the GNU General Public License applies
 *
 *  $Log: proto.h,v $
 *  Revision 1.17  1998/09/21 10:04:29  src
 *  Added new command line options for --inews
 *
 *  Revision 1.16  1998/09/14 06:30:25  src
 *  *** empty log message ***
 *
 *  Revision 1.15  1998/09/11 16:37:44  src
 *  Lockfile for logfile of posted articles and for posted article folder.
 *
 *  Revision 1.14  1998/09/11 09:17:43  src
 *  Check path consistency (--no-path) and length (--max-path)
 *  GNU style option --help, --version, --dry-run, changed --noxx to --no-xx
 *  Check for putenv and setenv, added xstrcpy
 *
 *  Revision 1.13  1998/09/09 07:32:13  src
 *  Version 1.1
 *
 *  Revision 1.12  1998/09/03 05:14:30  src
 *  Improved bad syntax messages
 *
 *  Revision 1.11  1998/09/03 02:49:30  src
 *  Fixed stuff detected by -Wall
 *
 *  Revision 1.10  1998/09/02 06:50:31  src
 *  newsx version 1.0
 *
 *  Revision 1.9  1998/09/02 06:34:41  src
 *  Support @-syntax in newsfeeds, and support AUTHINFO GENERIC
 */

/* doit.c */
int 
doit(void);
void
exit_cleanup(int exitcode);

/* statistics.c */
void        
statistics(time_t starttime,time_t endtime);

/* despool.c */
void 
despool(char *article_name);
char *
despool_line(void);

/* putarticle.c */
char *
submit_article(char *articlename);
int
is_tag(char *line, char *tag);

/* lock.c */
int
lock(char *dir_name,char *lock_name);
void 
unlock_one(int id);
void 
unlock_all(void);
void 
unlock_exit(int n);

/* util.c */
char *
news_home(void);
int 
append_file(FILE *f,char *name,FILE *af);
int 
rename_file(char *from,char *to);
time_t
what_date(FILE *f,char *name);
time_t
how_old(FILE *f, char *name);
int 
is_regular(FILE *f, char *name);
void 
build_alt_filename(char *where,char *home,char *fixed,char *alt);
void 
build_filename(char *where,char *arg1,char *arg2,char *arg3,char *arg4);
char *
text_time(time_t t);
void *
xmalloc(unsigned int size);
void * 
xrealloc(void *p,unsigned int size);
char *
xstrcpy(const char *str);

/* logmsg.c */
void 
log_open(void);
void
show_activity(void);
void 
log_msg(int type, char *fmt, ...);

/* server.c */
SOCKET_D *current_socket();
int 
open_server(char *host,char *port);
int
close_server(int urgent);
int 
get_server_nntp(char *line, int size);
int 
get_server_msg(char *line, int size);
int
put_server_nolog(char *line);
int
put_server(char *line);
int 
put_server_msg(char *line);
RETSIGTYPE 
sig_alrm(int signo);

/* socket.c */
int 
socket_open(char *hostname, char *service, SOCKET_D *sock);
void 
socket_close(SOCKET_D *sock);
int 
get_socket(char *line, int size, SOCKET_D *sock);
int 
put_socket(char *line, SOCKET_D *sock);

/* getarticle.c */
int 
select_group(char *group,long *firstp,long *lastp);
int 
fetch_article(long where,int more);

/* request.c */
int 
put_request(char *request, int (*fn)(), long where);
int 
process_request(void);
int 
flush_request(void);

/* pull.c */
int
pull(char *hostname);
void 
pull_cleanup(int urgent);

/* incoming.c */
int 
write_incoming(char *buffer,long bytecount,int is_a_path);
int 
flush_spool(int urgent);

/* active.c */
int 
is_active(char *group);
int 
is_in_active(char *group);
int 
unseen_active(char *group);
void 
load_active(void);
void
clear_active(void);
int
bad_syntax(char *buf,int was,int expect,char *where);

/* sys.c */
void 
load_sys(void);
int 
sys_allow(char *group);

/* auth.c */
void 
get_authinfo(char *file);
void 
do_authinfo(char *username,char *password);
void
do_mode_reader(void);

/* history.c */
void 
history_done(void);
int 
history_lookup(char *msgid);

/* msgid.c */
int 
new_msgid(char *msgid);

/* hash.c */
int 
hashindex(char *key,int hashlen);

/* exec.c */
int 
ctlinnd(char *arg1, char *arg2);
int 
script(char *program, int in, int out);
int        
wait_pid(int pid);
void 
program_open(char *program, SOCKET_D *sock);
FILE *
fork_write(char *path, int *pidp, char *arg1, char *arg2);
FILE *
open_any(char *any,int *pidp);
int     
close_any(FILE *f,int pid);

/* telnet.c */
int 
read_telnet(char *line, int size, SOCKET_D *sock);
int 
write_telnet(char *line, SOCKET_D *sock);

/* script.c */
void 
chat_update(char *line,SOCKET_D *sock);

/* title.c */
void 
begintitle(int argc, char **argv, char **envp);
void 
settitle(char *name);
void 
progtitle(char *what);
void 
progtitle2(char *what,char *more);

/* wildmat.c */
int 
wildmat(char *text, char *p);

/* bounce.c */
int  
bounce_msg(char *to, FILE *art,char *filename, char *msgid, char *reason);

/* rnews.c */
FILE *
open_rnews(int *pid);
int 
close_rnews(FILE *f, int pid);

/* mfilter.c */
int  
do_mfilter(char *msgid);

/* list.c */
void 
get_list(void);
void 
get_desc(void);

/* path.c */
void
add_exclusion(char *path);
char *
get_exclusion(void);
int
traverse_path(char *path);
int
path_bangs(char *path);
